// java wrapper for vtkImageOrthoPlanes object
//

package vtk;
import vtk.*;

public class vtkImageOrthoPlanes extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetPlane_2(int id0,vtkImagePlaneWidget id1);
  public void SetPlane(int id0,vtkImagePlaneWidget id1)
    { SetPlane_2(id0,id1); }

  private native long GetPlane_3(int id0);
  public vtkImagePlaneWidget GetPlane(int id0) {
    long temp = GetPlane_3(id0);

    if (temp == 0) return null;
    return (vtkImagePlaneWidget)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void ResetPlanes_4();
  public void ResetPlanes()
    { ResetPlanes_4(); }

  private native long GetTransform_5();
  public vtkTransform GetTransform() {
    long temp = GetTransform_5();

    if (temp == 0) return null;
    return (vtkTransform)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void HandlePlaneEvent_6(vtkImagePlaneWidget id0);
  public void HandlePlaneEvent(vtkImagePlaneWidget id0)
    { HandlePlaneEvent_6(id0); }

  public vtkImageOrthoPlanes() { super(); }

  public vtkImageOrthoPlanes(long id) { super(id); }
  public native long   VTKInit();

}
